@@ -72,6 +72,8 @@ class AgentLifeCycle:
     _docker_images["health_aggregator"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/health_aggregator:dev"
     _docker_images["smartplus_sound"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/smartplus_sound_server:latest"
     _docker_images["map_manager"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/map_manager:latest"
+    _docker_images["computer_health_metrics"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/ros:computer_health_metrics"
+    _docker_images["slamtec_adapter"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/slamtec_adapter:latest"
 
     def configure_containers(object, cfg):
         """
@@ -463,8 +465,19 @@ class AgentLifeCycle:
             args.config.config_path + "slamware_maps/": {"bind": "/root/.cognicept/slamware_maps", "mode": "rw"},
             args.config.config_path + "map_server_maps/": {"bind": "/root/.cognicept/map_server_maps", "mode": "rw"},
             args.config.config_path + "building_info.json": {"bind": "/home/map_manager_ws/src/map_manager/config/sample_building_info.json", "mode": "rw"}},
-            "network_mode": "host"}        
+            "network_mode": "host"}
         
+        # Computer Health Metrics run config
+        object._agent_run_options["computer_health_metrics"] = {"volumes": {
+            args.config.config_path + "health_config.yaml": {"bind": "/home/health_ws/src/computer_health_metrics/config/computer_params.yml", "mode": "rw"},
+            "/var/run/docker.sock/": {"bind": "/var/run/docker.sock/", "mode": "rw"}},
+             "network_mode": "host"}
+
+        # Slamware adapter run config
+        object._agent_run_options["slamtec_adapter"] = {"volumes": {
+            args.config.config_path + "slamware_maps/": {"bind": "/root/.cognicept/slamware_maps", "mode": "rw"}},
+            "network_mode": "host"}
+
         # Default other config
         object._agent_run_options["other"] = {
             "command": "", "network_mode": "host"}
