@@ -12,6 +12,10 @@ import re
 import jwt
 import requests
 import getpass
+import errno
+import shutil
+
+from cogniceptshell.common import bcolors
 
 
 class Configuration:
@@ -154,13 +158,33 @@ class Configuration:
                 Parameters:
                     None
         """
+        # Try backing up configuration before saving
+        backup_success = False
         try:
-            with open(object.env_path, 'w') as file:
-                for key, value in object.config.items():
-                    file.write(key + '=' + value + '\n')
-        except IOError:
-            print("Could not write into `" + object.env_path +
-                  "`. Please check write permission or run with `sudo`.")
+            shutil.copyfile(object.env_path, object.env_path+'.bk')
+            backup_success = True
+            print(bcolors.OKBLUE + "Backed up runtime configuration to: " + \
+                object.env_path + ".bk" + bcolors.ENDC)
+        except OSError as ex:
+            if ex.errno == errno.ENOSPC:
+                # Catch out of space exceptions
+                print(bcolors.FAIL + "Could not back up runtime configuration." + \
+                    " Aborting saving runtime configuration." + \
+                    " No space left on device!" + bcolors.ENDC)
+            else:
+                # Raise all other exceptions
+                print(bcolors.FAIL + "Could not back up runtime configuration." + \
+                    " Aborting saving runtime configuration: " + ex.strerror + bcolors.ENDC)
+        
+        # If backup is success, try to save it
+        if backup_success:
+            try:
+                with open(object.env_path, 'w') as file:
+                    for key, value in object.config.items():
+                        file.write(key + '=' + value + '\n')
+            except OSError:
+                print(bcolors.FAIL + "Could not write into `" + object.env_path +
+                    "`. Please check write permission or run with `sudo`." + bcolors.ENDC)        
 
     def get_cognicept_credentials(object):
         """
