@@ -4,9 +4,7 @@
 # --> RosbagRecord class handles on demand rosbag recording for cognicept-shell
 
 from dotenv import dotenv_values
-from pathlib import Path
 import os
-import sys
 import time
 from datetime import datetime, timedelta
 import glob
@@ -14,7 +12,7 @@ import docker
 from cogniceptshell.common import bcolors
 from cogniceptshell.agent_life_cycle import AgentLifeCycle
 from cogniceptshell.pusher import Pusher
-
+from cogniceptshell.common import permission_safe_docker_call
 
 class RosbagRecord:
     """
@@ -147,7 +145,10 @@ class RosbagRecord:
             selected_topics = ','.join(args.start)
             rosbag_start_cmd = rosbag_start_cmd + "'" + selected_topics + "'"
 
-        client = docker.from_env()
+        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        if permission_docker_call_result is None:
+            return False
+        client = permission_docker_call_result
         try:
             container = client.containers.get('cgs_bagger_server')
             num_retries = 3
@@ -199,7 +200,10 @@ class RosbagRecord:
                         args: populated argument namespace returned by `argparse.parse_args()`
         """
         rosbag_stop_cmd = "record_cmd.bash stop"
-        client = docker.from_env()
+        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        if permission_docker_call_result is None:
+            return False
+        client = permission_docker_call_result
         try:
             container = client.containers.get('cgs_bagger_server')
             num_retries = 3
@@ -253,7 +257,10 @@ class RosbagRecord:
                         args: populated argument namespace returned by `argparse.parse_args()`
         """
         rosbag_pause_cmd = "record_cmd.bash pause"
-        client = docker.from_env()
+        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        if permission_docker_call_result is None:
+            return False
+        client = permission_docker_call_result
         try:
             container = client.containers.get('cgs_bagger_server')
             num_retries = 3
@@ -294,7 +301,10 @@ class RosbagRecord:
                         args: populated argument namespace returned by `argparse.parse_args()`
         """
         rosbag_resume_cmd = "record_cmd.bash resume"
-        client = docker.from_env()
+        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        if permission_docker_call_result is None:
+            return False
+        client = permission_docker_call_result
         try:
             container = client.containers.get('cgs_bagger_server')
             num_retries = 3
@@ -335,7 +345,10 @@ class RosbagRecord:
                         args: populated argument namespace returned by `argparse.parse_args()`
         """
         rosbag_status_cmd = "record_cmd.bash status"
-        client = docker.from_env()
+        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        if permission_docker_call_result is None:
+            return False
+        client = permission_docker_call_result
         try:
             container = client.containers.get('cgs_bagger_server')
             num_retries = 3
